<?php
#A


#B


#C
$lang['count_itemtype'] = 'Count items of the same type as individual items';

#D


#E


#F
$lang['friendlyname'] = 'Calculate Shipping Per Item';

#G


#H
$lang['help'] = <<<EOT
TODO
EOT;

#I
$lang['info_count_itemtype'] = 'If this option is selected, multiple items of the same type will be counted separately when calculating costs';
$lang['info_itemprice'] = 'Specify the shipping cost per item.  If the shipping field is not specified, or is invalid for the product this value is used as the shipping cost for an item';
$lang['info_shipping_field'] = 'Specify the custom field from the Products module that will hold a shipping price for an item';
$lang['itemprice'] = 'Per Item Price';

#J


#K


#L


#M
$lang['moddescription'] = 'A moduel that calculates fixed shipping costs based purely on the number of items';

#N
$lang['none'] = 'None';

#O


#P
$lang['postinstall'] = 'PerItemShipping module installed, please configure it';
$lang['postuninstall'] = 'All data for PerItemShipping module has been removed';
$lang['preferences'] = 'Preferences';

#Q


#R
$lang['really_uninstall'] = 'Are you sure you want to uninstall this module?';

#S
$lang['shipping_field'] = 'Products Shipping Field';
$lang['submit'] = 'Submit';

#T


#U


#V


#W


#X


#Y


#Z


?>